@@ -1,3 +1,9 @@
+#[derive(Debug)]
+pub enum ApiErrors {
+    ApiError(ApiError),
+    DieselError(diesel::result::Error),
+}
+
 #[derive(Debug)]
 pub struct ApiError {
     pub status: rocket::http::Status,
