@@ -1,5 +1,5 @@
 pub mod api;
-pub mod error;
+#[macro_use] pub mod error;
 
 pub use api::ApiResponse;
 pub use api::ApiResponseErr;
